"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const airtable_data_provider_1 = require("./airtable_data_provider");
const airtable_schema_provider_1 = require("./airtable_schema_provider");
const sql_filter_transformer_1 = require("./sql_filter_transformer");
const airtable_operations_1 = require("./airtable_operations");
const Airtable = require("airtable");
const extraOptions = (cfg) => {
    if (cfg.baseUrl)
        return { endpointUrl: cfg.baseUrl };
    return {};
};
exports.default = (cfg, _cfgOptions) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const options = _cfgOptions || {};
    const airtableBase = new Airtable(Object.assign(Object.assign({ apiKey: cfg.apiPrivateKey }, extraOptions(cfg)), options)).base(cfg.baseId);
    const databaseOperations = new airtable_operations_1.default(airtableBase);
    const filterParser = new sql_filter_transformer_1.default();
    const dataProvider = new airtable_data_provider_1.default(airtableBase, filterParser);
    const schemaProvider = new airtable_schema_provider_1.default(airtableBase, { apiKey: cfg.apiPrivateKey, metaApiKey: cfg.metaApiKey, baseUrl: cfg.baseUrl });
    return { dataProvider, schemaProvider, connection: airtableBase, databaseOperations, cleanup: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { }) };
});
//# sourceMappingURL=connection_provider.js.map